@@ -10,7 +10,6 @@ use Doctrine\ORM\Mapping\Builder\EntityListenerBuilder;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\Persistence\Mapping\ClassMetadata as PersistenceClassMetadata;
-use Doctrine\Persistence\Mapping\Driver\ClassLocator;
 use Doctrine\Persistence\Mapping\Driver\ColocatedMappingDriver;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use InvalidArgumentException;
@@ -36,10 +35,10 @@ class AttributeDriver implements MappingDriver
     private readonly AttributeReader $reader;
 
     /**
-     * @param string[]|ClassLocator $paths                     a ClassLocator, or an array of directories.
-     * @param true                  $reportFieldsWhereDeclared no-op, to be removed in 4.0
+     * @param array<string> $paths
+     * @param true          $reportFieldsWhereDeclared no-op, to be removed in 4.0
      */
-    public function __construct(array|ClassLocator $paths, bool $reportFieldsWhereDeclared = true)
+    public function __construct(array $paths, bool $reportFieldsWhereDeclared = true)
     {
         if (! $reportFieldsWhereDeclared) {
             throw new InvalidArgumentException(sprintf(
@@ -49,12 +48,7 @@ class AttributeDriver implements MappingDriver
         }
 
         $this->reader = new AttributeReader();
-
-        if ($paths instanceof ClassLocator) {
-            $this->classLocator = $paths;
-        } else {
-            $this->addPaths($paths);
-        }
+        $this->addPaths($paths);
     }
 
     public function isTransient(string $className): bool
