@@ -13,9 +13,10 @@ use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Persisters\Entity\EntityPersister;
 use Doctrine\Tests\Models\Cache\Country;
+use PHPUnit\Framework\Attributes\Group;
 use ReflectionProperty;
 
-/** @group DDC-2183 */
+#[Group('DDC-2183')]
 class NonStrictReadWriteCachedEntityPersisterTest extends EntityPersisterTestCase
 {
     protected function createPersister(EntityManagerInterface $em, EntityPersister $persister, Region $region, ClassMetadata $metadata): AbstractEntityPersister
@@ -29,8 +30,6 @@ class NonStrictReadWriteCachedEntityPersisterTest extends EntityPersisterTestCas
         $persister = $this->createPersisterDefault();
         $property  = new ReflectionProperty($persister, 'queuedCache');
 
-        $property->setAccessible(true);
-
         $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
         $persister->update($entity);
@@ -51,8 +50,6 @@ class NonStrictReadWriteCachedEntityPersisterTest extends EntityPersisterTestCas
         $entry     = new EntityCacheEntry(Country::class, ['id' => 1, 'name' => 'Foo']);
         $property  = new ReflectionProperty($persister, 'queuedCache');
 
-        $property->setAccessible(true);
-
         $this->region->expects(self::once())
             ->method('put')
             ->with(self::equalTo($key), self::equalTo($entry));
@@ -88,8 +85,6 @@ class NonStrictReadWriteCachedEntityPersisterTest extends EntityPersisterTestCas
         $entry     = new EntityCacheEntry(Country::class, ['id' => 1, 'name' => 'Foo']);
         $property  = new ReflectionProperty($persister, 'queuedCache');
 
-        $property->setAccessible(true);
-
         $this->region->expects(self::once())
             ->method('put')
             ->with(self::equalTo($key), self::equalTo($entry));
@@ -116,8 +111,6 @@ class NonStrictReadWriteCachedEntityPersisterTest extends EntityPersisterTestCas
         $key       = new EntityCacheKey(Country::class, ['id' => 1]);
         $property  = new ReflectionProperty($persister, 'queuedCache');
 
-        $property->setAccessible(true);
-
         $this->region->expects(self::once())
             ->method('evict')
             ->with(self::equalTo($key));
