@@ -18,6 +18,7 @@ use PHPUnit\Framework\Attributes\Group;
 
 use function assert;
 use function class_exists;
+use function get_class;
 
 /**
  * Basic many-to-many association tests.
@@ -436,7 +437,7 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
 
         $user = $this->_em->find($user::class, $user->id);
 
-        $criteria = Criteria::create()
+        $criteria = Criteria::create(true)
             ->orderBy(['name' => class_exists(Order::class) ? Order::Ascending : Criteria::ASC]);
 
         self::assertEquals(
@@ -476,7 +477,7 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
 
         $user = $this->_em->find($user::class, $user->id);
 
-        $criteria = Criteria::create()
+        $criteria = Criteria::create(true)
             ->orderBy(['name' => class_exists(Order::class) ? Order::Ascending : Criteria::ASC]);
 
         self::assertEquals(
@@ -499,7 +500,7 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
         $groups = $user->groups;
         self::assertFalse($user->groups->isInitialized(), 'Pre-condition: lazy collection');
 
-        $criteria = Criteria::create()->setMaxResults(1);
+        $criteria = Criteria::create(true)->setMaxResults(1);
         $result   = $groups->matching($criteria);
 
         self::assertCount(1, $result);
@@ -517,7 +518,7 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
         $groups = $user->groups;
         self::assertFalse($user->groups->isInitialized(), 'Pre-condition: lazy collection');
 
-        $criteria = Criteria::create()->setFirstResult(1);
+        $criteria = Criteria::create(true)->setFirstResult(1);
         $result   = $groups->matching($criteria);
 
         self::assertCount(1, $result);
@@ -538,7 +539,7 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
         $groups = $user->groups;
         self::assertFalse($user->groups->isInitialized(), 'Pre-condition: lazy collection');
 
-        $criteria = Criteria::create()->setFirstResult(1)->setMaxResults(3);
+        $criteria = Criteria::create(true)->setFirstResult(1)->setMaxResults(3);
         $result   = $groups->matching($criteria);
 
         self::assertCount(3, $result);
@@ -562,7 +563,7 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
         $groups = $user->groups;
         self::assertFalse($user->groups->isInitialized(), 'Pre-condition: lazy collection');
 
-        $criteria = Criteria::create()->where(Criteria::expr()->eq('name', (string) 'Developers_0'));
+        $criteria = Criteria::create(true)->where(Criteria::expr()->eq('name', (string) 'Developers_0'));
         $result   = $groups->matching($criteria);
 
         self::assertCount(1, $result);
@@ -573,6 +574,44 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
         self::assertFalse($user->groups->isInitialized(), 'Post-condition: matching does not initialize collection');
     }
 
+    public function testMatchingWithInCondition(): void
+    {
+        $user = $this->addCmsUserGblancoWithGroups(2);
+        $this->_em->clear();
+
+        $user = $this->_em->find(get_class($user), $user->id);
+
+        $groups = $user->groups;
+        self::assertFalse($user->groups->isInitialized(), 'Pre-condition: lazy collection');
+
+        $criteria = Criteria::create(true)->where(Criteria::expr()->in('name', ['Developers_1']));
+        $result   = $groups->matching($criteria);
+
+        self::assertCount(1, $result);
+        self::assertEquals('Developers_1', $result[0]->name);
+
+        self::assertFalse($user->groups->isInitialized(), 'Post-condition: matching does not initialize collection');
+    }
+
+    public function testMatchingWithNotInCondition(): void
+    {
+        $user = $this->addCmsUserGblancoWithGroups(2);
+        $this->_em->clear();
+
+        $user = $this->_em->find(get_class($user), $user->id);
+
+        $groups = $user->groups;
+        self::assertFalse($user->groups->isInitialized(), 'Pre-condition: lazy collection');
+
+        $criteria = Criteria::create(true)->where(Criteria::expr()->notIn('name', ['Developers_0']));
+        $result   = $groups->matching($criteria);
+
+        self::assertCount(1, $result);
+        self::assertEquals('Developers_1', $result[0]->name);
+
+        self::assertFalse($user->groups->isInitialized(), 'Post-condition: matching does not initialize collection');
+    }
+
     private function removeTransactionCommandsFromQueryLog(): void
     {
         $log = $this->getQueryLog();
